package com.xinelu.manage.mapper.patientvisitrecord;

import com.xinelu.manage.domain.patientvisitrecord.PatientVisitRecord;
import com.xinelu.manage.dto.patientvisitrecord.PatientVisitRecordDto;
import com.xinelu.manage.dto.statistics.FollowUpRateDto;
import com.xinelu.manage.vo.patientvisitrecord.PatientVisitRecordStatisticVo;
import com.xinelu.manage.vo.patientvisitrecord.PatientVisitRecordVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 患者就诊记录基本信息Mapper接口
 *
 * @author haown
 * @date 2024-02-26
 */
public interface PatientVisitRecordMapper {
    /**
     * 查询患者就诊记录基本信息
     *
     * @param id 患者就诊记录基本信息主键
     * @return 患者就诊记录基本信息
     */
    PatientVisitRecord selectPatientVisitRecordById(Long id);

	/**
	 * 查询患者最新一条就诊记录信息
	 * @param patientId 患者记录表主键
	 * @return 患者就诊信息视图类
	 */
	PatientVisitRecordVo getByPatientId(Long patientId);

    /**
     * 查询患者就诊记录基本信息列表
     *
     * @param patientVisitRecord 患者就诊记录基本信息
     * @return 患者就诊记录基本信息集合
     */
    List<PatientVisitRecord> selectPatientVisitRecordList(PatientVisitRecordDto patientVisitRecord);

    /**
     * 新增患者就诊记录基本信息
     *
     * @param patientVisitRecord 患者就诊记录基本信息
     * @return 结果
     */
    int insertPatientVisitRecord(PatientVisitRecord patientVisitRecord);

	int insertBatch(@Param("patientVisitRecordList") List<PatientVisitRecord> patientVisitRecordList);
    /**
     * 修改患者就诊记录基本信息
     *
     * @param patientVisitRecord 患者就诊记录基本信息
     * @return 结果
     */
    int updatePatientVisitRecord(PatientVisitRecord patientVisitRecord);

    /**
     * 删除患者就诊记录基本信息
     *
     * @param id 患者就诊记录基本信息主键
     * @return 结果
     */
    int deletePatientVisitRecordById(Long id);

    /**
     * 批量删除患者就诊记录基本信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deletePatientVisitRecordByIds(Long[] ids);

	/**
	 * 根据查询条件获取最新一条就诊记录
	 * @param patientVisitRecordDto 患者就诊记录查询传输对象
	 * @return 就诊记录信息
	 */
	PatientVisitRecord getLastRecord(PatientVisitRecordDto patientVisitRecordDto);

	List<PatientVisitRecordStatisticVo> getVisitPatientList(FollowUpRateDto queryDto);

    /**
     * 批量新增就诊记录
     *
     * @param patientVisitRecordList 就诊记录
     * @return int
     */
    int insertPatientVisitRecordList(List<PatientVisitRecord> patientVisitRecordList);
}
